@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkImageIOBase.h,v $
   Language:  C++
-  Date:      $Date: 2009-02-22 05:53:41 $
-  Version:   $Revision: 1.51 $
+  Date:      $Date: 2009-07-02 13:16:48 $
+  Version:   $Revision: 1.54 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -172,17 +172,17 @@ public:
 
   /** Set/Get a boolean to use the compression or not. */
   itkSetMacro(UseCompression,bool);
-  itkGetMacro(UseCompression,bool);
+  itkGetConstMacro(UseCompression,bool);
   itkBooleanMacro(UseCompression);
 
   /** Set/Get a boolean to use streaming while reading or not. */
   itkSetMacro(UseStreamedReading,bool);
-  itkGetMacro(UseStreamedReading,bool);
+  itkGetConstMacro(UseStreamedReading,bool);
   itkBooleanMacro(UseStreamedReading);
 
   /** Set/Get a boolean to use streaming while writing or not. */
   itkSetMacro(UseStreamedWriting,bool);
-  itkGetMacro(UseStreamedWriting,bool);
+  itkGetConstMacro(UseStreamedWriting,bool);
   itkBooleanMacro(UseStreamedWriting);
 
 
@@ -249,7 +249,11 @@ public:
   typedef std::streamoff SizeType;
 
   /** Convenient method for accessing the number of bytes to get to
-   * the next pixel. Returns m_Strides[1]; */
+   * the next pixel. Returns m_Strides[1]; 
+   * 
+   * Please note that this methods depends the private methods
+   * ComputeStrides being called, otherwise this is the incorrect value.
+   */
   virtual SizeType GetPixelStride () const;
 
   /** Return the number of pixels in the image. */
@@ -262,6 +266,14 @@ public:
    * of components in the image. */
   SizeType GetImageSizeInComponents() const;
 
+
+  /** Compute the size (in bytes) of the components of a pixel. For
+   * example, and RGB pixel of unsigned char would have a 
+   * component size of 1 byte. This method can be invoked only after
+   * the component type is set. */
+  virtual unsigned int GetComponentSize() const;
+
+
   /*-------- This part of the interfaces deals with reading data ----- */
 
   /** Determine the file type. Returns true if this ImageIO can read the
@@ -322,8 +334,15 @@ public:
 
   /** Method for supporting streaming.  Given a requested region, determine what
    * could be the region that we can read from the file. This is called the
-   * streamable region, which will be smaller than the LargestPossibleRegion and
-   * greater or equal to the RequestedRegion */
+   * streamable region, which will be equal or smaller than the
+   * LargestPossibleRegion (unless it was dimensionaly clipped) and
+   * greater or equal to the RequestedRegion
+   *
+   * the resulting IORegion may be a greater dimensions the the
+   * requested IORegion, if the the derived class is unable to read
+   * the requested region. For example if the file has a size of [ 10,
+   * 10, 10] but the requested region is [10, 10] the return may be 3 dimensions.
+   */
   virtual ImageIORegion 
   GenerateStreamableReadRegionFromRequestedRegion( const ImageIORegion & requested ) const;
 
@@ -337,9 +356,11 @@ public:
    * If pasted is enabled and is not support or does not work with the file, 
    * then an excepetion should be thrown. 
    *
-   * The default implementation depends on CanStreamWrite. 
+   * The default implementation depends on CanStreamWrite.
    * If false then 1 is returned (unless pasting is indicated), so that the whole file will be updated in one region.
-   * If true then its assumed that any arbitrary region can be writen to any file. So the users request will be respected. If a derived class has more restictive conditions then they should be checked
+   * If true then its assumed that any arbitrary region can be writen
+   * to any file. So the users request will be respected. If a derived
+   * class has more restictive conditions then they should be checked
    */
   virtual unsigned int GetActualNumberOfSplitsForWriting(unsigned int numberOfRequestedSplits,
                                                          const ImageIORegion &pasteRegion,
@@ -438,6 +459,10 @@ protected:
   void Resize(const unsigned int numDimensions, 
               const unsigned int* dimensions);
 
+  /** Compute the size (in bytes) of the pixel. For
+   * example, and RGB pixel of unsigned char would have size 3 bytes. */
+  virtual unsigned int GetPixelSize() const;
+
   /** Calculates the different strides (distance from one thing to the next).
    * Upon return,
    * strides[0] = bytes to get to the next component of a pixel,
@@ -446,16 +471,6 @@ protected:
    * strides[3] = bytes to get to the next slice in z direction, etc. */
   void ComputeStrides();
 
-  /** Compute the size (in bytes) of the pixel. For
-   * example, and RGB pixel of unsigned char would have size 3 bytes. */
-  virtual unsigned int GetPixelSize() const;
-
-  /** Compute the size (in bytes) of the components of a pixel. For
-   * example, and RGB pixel of unsigned char would have a 
-   * component size of 1 byte. This method can be invoked only after
-   * the component type is set. */
-  virtual unsigned int GetComponentSize() const;
-
   /** Convenient method for accessing number of bytes to get to the next pixel 
    * component. Returns m_Strides[0]. */
   SizeType GetComponentStride() const;
