@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkMovingHistogramMorphologyImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2009-04-23 03:43:42 $
-  Version:   $Revision: 1.4 $
+  Date:      $Date: 2009-06-03 12:48:05 $
+  Version:   $Revision: 1.5 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -30,7 +30,7 @@ class MorphologyHistogram
 public:
   MorphologyHistogram()
     {
-    if( useVectorBasedAlgorithm() )
+    if( UseVectorBasedAlgorithm() )
       { initVector(); }
     }
   ~MorphologyHistogram(){}
@@ -52,7 +52,7 @@ public:
 
   inline void AddBoundary()
     {
-    if( useVectorBasedAlgorithm() )
+    if( UseVectorBasedAlgorithm() )
       { AddBoundaryVector(); }
     else
       { AddBoundaryMap(); }
@@ -60,7 +60,7 @@ public:
 
   inline void RemoveBoundary()
     {
-    if( useVectorBasedAlgorithm() )
+    if( UseVectorBasedAlgorithm() )
       { RemoveBoundaryVector(); }
     else
       { RemoveBoundaryMap(); }
@@ -68,7 +68,7 @@ public:
 
   inline void AddPixel( const TInputPixel &p )
     {
-    if( useVectorBasedAlgorithm() )
+    if( UseVectorBasedAlgorithm() )
       { AddPixelVector( p ); }
     else
       { AddPixelMap( p ); }
@@ -76,7 +76,7 @@ public:
 
   inline void RemovePixel( const TInputPixel &p )
     {
-    if( useVectorBasedAlgorithm() )
+    if( UseVectorBasedAlgorithm() )
       { RemovePixelVector( p ); }
     else
       { RemovePixelMap( p ); }
@@ -84,14 +84,14 @@ public:
 
   inline TInputPixel GetValue( const TInputPixel & )
     {
-    if( useVectorBasedAlgorithm() )
+    if( UseVectorBasedAlgorithm() )
       { return GetValueVector(); }
     else
       { return GetValueMap(); }
     }
 
 
-  inline static bool useVectorBasedAlgorithm()
+  inline static bool UseVectorBasedAlgorithm()
     {
     // bool, short and char are acceptable for vector based algorithm: they do not require
     // too much memory. Other types are not usable with that algorithm
@@ -277,7 +277,7 @@ public:
   /** Return true if the vector based algorithm is used, and
    * false if the map based algorithm is used */
   static bool GetUseVectorBasedAlgorithm()
-    { return THistogram::useVectorBasedAlgorithm(); }
+    { return THistogram::UseVectorBasedAlgorithm(); }
   
 protected:
   MovingHistogramMorphologyImageFilter();
